==> Botania-1.16.4-411-FABRIC-20210109.224042-7-sources.jar: vazkii/botania/client/model/DelegatedModel.java <==
/*
 * This class is distributed as part of the Botania Mod.
 * Get the Source Code in github:
 * https://github.com/Vazkii/Botania
 *
 * Botania is Open Source and distributed under the
 * Botania License: http://botaniamod.net/license.php
 */
package vazkii.botania.client.model;

import javax.annotation.Nullable;
import net.minecraft.class_1058;
import net.minecraft.class_1087;
import net.minecraft.class_2350;
import net.minecraft.class_2680;
import net.minecraft.class_777;
import net.minecraft.class_806;
import net.minecraft.class_809;
import java.util.List;
import java.util.Random;

public class DelegatedModel implements class_1087 {
	protected final class_1087 originalModel;

	public DelegatedModel(class_1087 originalModel) {
		this.originalModel = originalModel;
	}

	@Override
	public boolean method_4708() {
		return originalModel.method_4708();
	}

	@Override
	public boolean method_4712() {
		return originalModel.method_4712();
	}

	@Override
	public boolean method_24304() {
		return originalModel.method_24304();
	}

	@Override
	public boolean method_4713() {
		return originalModel.method_4713();
	}

	@Override
	public class_1058 method_4711() {
		return originalModel.method_4711();
	}

	@Override
	public class_809 method_4709() {
		return originalModel.method_4709();
	}

	@Override
	public class_806 method_4710() {
		return originalModel.method_4710();
	}

	@Override
	public List<class_777> method_4707(@Nullable class_2680 state, @Nullable class_2350 side, Random rand) {
		return null;
	}
}

==> Botania-1.20.1-451-FABRIC-20251214.151426-36-sources.jar: vazkii/botania/client/model/DelegatedModel.java <==
/*
 * This class is distributed as part of the Botania Mod.
 * Get the Source Code in github:
 * https://github.com/Vazkii/Botania
 *
 * Botania is Open Source and distributed under the
 * Botania License: http://botaniamod.net/license.php
 */
package vazkii.botania.client.model;

import org.jetbrains.annotations.Nullable;

import java.util.List;
import net.minecraft.class_1058;
import net.minecraft.class_1087;
import net.minecraft.class_2350;
import net.minecraft.class_2680;
import net.minecraft.class_5819;
import net.minecraft.class_777;
import net.minecraft.class_806;
import net.minecraft.class_809;

public class DelegatedModel implements class_1087 {
	protected final class_1087 originalModel;

	public DelegatedModel(class_1087 originalModel) {
		this.originalModel = originalModel;
	}

	@Override
	public boolean method_4708() {
		return originalModel.method_4708();
	}

	@Override
	public boolean method_4712() {
		return originalModel.method_4712();
	}

	@Override
	public boolean method_24304() {
		return originalModel.method_24304();
	}

	@Override
	public boolean method_4713() {
		return originalModel.method_4713();
	}

	@Override
	public class_1058 method_4711() {
		return originalModel.method_4711();
	}

	@Override
	public class_809 method_4709() {
		return originalModel.method_4709();
	}

	@Override
	public class_806 method_4710() {
		return originalModel.method_4710();
	}

	@Override
	public List<class_777> method_4707(@Nullable class_2680 state, @Nullable class_2350 side, class_5819 rand) {
		return null;
	}
}
